<?php

/**
 * @file
 *
 * Support for migrating comments from a Cultura Exchange.
 */

/**
 * Implementation of CulturaExchangeMigration for comments.
 */
class CulturaExchangeComment extends CulturaExchangeMigration {
  /**
   * Set it up
   */
  public function __construct(array $arguments = array()) {
    $arguments['post_type'] = 'comment_node_' . CULTURA_DISCUSSION_NODE_TYPE;
    parent::__construct($arguments);
    $this->dependencies = array($this->generateMachineName('CulturaExchangeNode'));

    $fields = array(
      'nid' => 'Unique ID of the item the comment is attached to',
      'cid' => 'Unique ID of the comment',
      'author' => 'Name of comment author',
      'post_date' => 'Date of comment',
      'comment' => 'Body of comment',
    );

    // comment_id is the unique ID of comments on discussions.
    $this->map = new MigrateSQLMap($this->machineName,
      array(
        'cid' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'not null' => TRUE,
          'description' => 'Comment ID',
        )
      ),
      MigrateDestinationComment::getKeySchema()
    );
    $items_url = $this->xmlFile;
    $item_xpath = '/site_export/comments/comment';
    $item_ID_xpath = 'cid';

    $items_class = new MigrateItemsXML($items_url, $item_xpath, $item_ID_xpath);
    $this->source = new MigrateSourceMultiItems($items_class, $fields);

    $this->destination = new MigrateDestinationComment($arguments['post_type']);

    // The basic mappings
    $this->addFieldMapping('nid', 'nid')
      ->xpath('nid')
         ->sourceMigration($this->generateMachineName('CulturaExchangeNode'));
    $this->addFieldMapping('created', 'post_date')->xpath('post_date');
    $this->addFieldMapping('changed', 'post_date')->xpath('post_date');
    $this->addFieldMapping('name', 'author')->xpath('author');
    $text_format = variable_get('culturaexchange_migrate_text_format_comment', 'filtered_html');
    $this->addFieldMapping('comment_body', 'comment')->xpath('comment');
    $this->addFieldMapping('comment_body:format')->defaultValue($text_format);

    // Unmapped destination fields
    $this->addUnmigratedDestinations(array('language', 'status', 'path'));

    // Unmapped source fields
    $this->addUnmigratedSources(array('cid'));
  }
}
